@@ -224,6 +224,8 @@ def lazify(data, output_field: Union[list, str], f, rnd, multi_output) -> Union[
         step = f.metadata.copy()
         if "id" in step:
             newidx = step.pop("id")
+            if "_" in newidx:
+                raise Exception(f"'id' cannot have '_': {newidx}")
         for k in ["input", "output", "function"]:
             if k in step:
                 del step[k]
@@ -280,6 +282,8 @@ def lazify(data, output_field: Union[list, str], f, rnd, multi_output) -> Union[
                     last = list(data["_history"].keys())[-1]
                     if isinstance(last, int):
                         newidx = last + 1
+                    elif newidx == 0:
+                        newidx = ...
                     dic["_history"] = data["_history"].copy()
                 else:
                     dic["_history"] = {}
